==> pear-Horde_Imap_Client-1.5.1.tbz: share/pear/Horde/Imap/Client/Translation.php <==
<?php
/**
 * Copyright 2010-2012 Horde LLC (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (LGPL). If you
 * did not receive this file, see http://www.horde.org/licenses/lgpl21.
 *
 * @author   Michael Slusarz <slusarz@curecanti.org>
 * @category Horde
 * @license  http://www.horde.org/licenses/lgpl21 LGPL
 * @package  Imap_Client
 */

/**
 * Translation wrapper class for Horde_Imap_Client.
 *
 * @author   Michael Slusarz <slusarz@curecanti.org>
 * @category Horde
 * @license  http://www.horde.org/licenses/lgpl21 LGPL
 * @package  Imap_Client
 */
class Horde_Imap_Client_Translation extends Horde_Translation
{
    /**
     * Returns the translation of a message.
     *
     * @var string $message  The string to translate.
     *
     * @return string  The string translation, or the original string if no
     *                 translation exists.
     */
    static public function t($message)
    {
        self::$_domain = 'Horde_Imap_Client';
        self::$_directory = '/usr/local/share/pear/data' == '@'.'data_dir'.'@' ? dirname(__FILE__) . '/../../../../locale' : '/usr/local/share/pear/data/Horde_Imap_Client/locale';
        return parent::t($message);
    }

    /**
     * Returns the plural translation of a message.
     *
     * @param string $singular  The singular version to translate.
     * @param string $plural    The plural version to translate.
     * @param integer $number   The number that determines singular vs. plural.
     *
     * @return string  The string translation, or the original string if no
     *                 translation exists.
     */
    static public function ngettext($singular, $plural, $number)
    {
        self::$_domain = 'Horde_Imap_Client';
        self::$_directory = '/usr/local/share/pear/data' == '@'.'data_dir'.'@' ? dirname(__FILE__) . '/../../../../locale' : '/usr/local/share/pear/data/Horde_Imap_Client/locale';
        return parent::ngettext($singular, $plural, $number);
    }
}

==> pear-Horde_Imap_Client-2.8.2.tbz: share/pear/Horde/Imap/Client/Translation.php <==
<?php
/**
 * Copyright 2010-2013 Horde LLC (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (LGPL). If you
 * did not receive this file, see http://www.horde.org/licenses/lgpl21.
 *
 * @category  Horde
 * @copyright 2010-2013 Horde LLC
 * @license   http://www.horde.org/licenses/lgpl21 LGPL
 * @package   Imap_Client
 */

/**
 * Translation wrapper class for Horde_Imap_Client.
 *
 * @author    Michael Slusarz <slusarz@horde.org>
 * @category  Horde
 * @copyright 2010-2013 Horde LLC
 * @license   http://www.horde.org/licenses/lgpl21 LGPL
 * @package   Imap_Client
 */
class Horde_Imap_Client_Translation extends Horde_Translation
{
    /**
     * Returns the translation of a message.
     *
     * @var string $message  The string to translate.
     *
     * @return string  The string translation, or the original string if no
     *                 translation exists.
     */
    static public function t($message)
    {
        self::$_domain = 'Horde_Imap_Client';
        self::$_directory = '/usr/local/share/pear/data' == '@'.'data_dir'.'@' ? __DIR__ . '/../../../../locale' : '/usr/local/share/pear/data/Horde_Imap_Client/locale';
        return parent::t($message);
    }

    /**
     * Returns the plural translation of a message.
     *
     * @param string $singular  The singular version to translate.
     * @param string $plural    The plural version to translate.
     * @param integer $number   The number that determines singular vs. plural.
     *
     * @return string  The string translation, or the original string if no
     *                 translation exists.
     */
    static public function ngettext($singular, $plural, $number)
    {
        self::$_domain = 'Horde_Imap_Client';
        self::$_directory = '/usr/local/share/pear/data' == '@'.'data_dir'.'@' ? __DIR__ . '/../../../../locale' : '/usr/local/share/pear/data/Horde_Imap_Client/locale';
        return parent::ngettext($singular, $plural, $number);
    }
}
